pub struct CTEmpty;Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CTEmpty
impl<'de> Deserialize<'de> for CTEmpty
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromXml for CTEmpty
impl FromXml for CTEmpty
Sourcefn from_xml<R: BufRead>(
reader: &mut Reader<R>,
_start: &BytesStart<'_>,
is_empty: bool,
) -> Result<Self, ParseError>
fn from_xml<R: BufRead>( reader: &mut Reader<R>, _start: &BytesStart<'_>, is_empty: bool, ) -> Result<Self, ParseError>
Parse from an XML reader positioned at the start tag. Read more
Sourceimpl ToXml for CTEmpty
impl ToXml for CTEmpty
Sourcefn is_empty_element(&self) -> bool
fn is_empty_element(&self) -> bool
Whether this element has no children (self-closing).
Sourcefn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
fn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
Write attributes onto the start tag and return it.
Sourcefn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write child elements and text content inside the element.
Sourcefn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write a complete element:
<tag attrs>children</tag> or <tag attrs/>.Auto Trait Implementations
impl Freeze for CTEmpty
impl RefUnwindSafe for CTEmpty
impl Send for CTEmpty
impl Sync for CTEmpty
impl Unpin for CTEmpty
impl UnsafeUnpin for CTEmpty
impl UnwindSafe for CTEmpty