TransitionType

Enum TransitionType 

pub enum TransitionType {
Show 19 variants Fade, Push, Wipe, Split, Blinds, Checker, Circle, Dissolve, Comb, Cover, Cut, Diamond, Plus, Random, Strips, Wedge, Wheel, Zoom, Other(String),
}
Type of slide transition effect.

Variants



Fade

Fade transition.



Push

Push transition.



Wipe

Wipe transition.



Split

Split transition.



Blinds

Blinds transition.



Checker

Checker transition.



Circle

Circle transition.



Dissolve

Dissolve transition.



Comb

Comb transition.



Cover

Cover transition.



Cut

Cut transition.



Diamond

Diamond transition.



Plus

Plus transition.



Random

Random transition.



Strips

Strips transition.



Wedge

Wedge transition.



Wheel

Wheel transition.



Zoom

Zoom transition.



Other(String)

Unknown/unsupported transition type.

Implementations

Source

impl TransitionType

pub fn to_xml_value(&self) -> &str

Convert to XML element name.